package thehippomaster.animationapi.client.model.wavefront;

import org.lwjgl.opengl.GL11;

import java.util.ArrayList;
import java.util.Hashtable;

public class Part
{
  public ArrayList<FaceGroup> faceGroup;
  public Hashtable<String, Float> nameToFloatHash;
  public String partName;
  private ArrayList<Vertex> vertices;
  private ArrayList<UV> uv;
  private double minX;
  private double minY;
  private double minZ;
  private double maxX;
  private double maxY;
  private double maxZ;
  private float oX;
  private float oY;
  private float oZ;
  private float oX2;
  private float oY2;
  private float oZ2;
  
  void addVertex(Vertex v)
  {
    this.vertices.add(v);
    this.minX = Math.min(this.minX, v.x);
    this.minY = Math.min(this.minY, v.y);
    this.minZ = Math.min(this.minZ, v.z);
    this.maxX = Math.max(this.maxX, v.x);
    this.maxY = Math.max(this.maxY, v.y);
    this.maxZ = Math.max(this.maxZ, v.z);
  }
  
  public Part(String name, ArrayList<Vertex> vertex, ArrayList<UV> uv)
  {
    this.partName = name;
    this.faceGroup = new ArrayList();
    this.nameToFloatHash = new Hashtable();
    this.vertices = vertex;
    this.uv = uv;
  }
  
  public float getFloat(String name)
  {
    return ((Float)this.nameToFloatHash.get(name)).floatValue();
  }
  
  public void draw(float angle, float x, float y, float z)
  {
    GL11.glPushMatrix();
    GL11.glTranslatef(this.oX, this.oY, this.oZ);
    GL11.glRotatef(angle, x, y, z);
    GL11.glTranslatef(-this.oX, -this.oY, -this.oZ);
    draw();
    GL11.glPopMatrix();
  }
  
  public void draw(float angle, float x, float y, float z, float angle2, float x2, float y2, float z2)
  {
    GL11.glPushMatrix();
    GL11.glTranslatef(this.oX, this.oY, this.oZ);
    GL11.glRotatef(angle, x, y, z);
    GL11.glTranslatef(this.oX2, this.oY2, this.oZ2);
    GL11.glRotatef(angle2, x2, y2, z2);
    GL11.glTranslatef(-this.oX2, -this.oY2, -this.oZ2);
    GL11.glTranslatef(-this.oX, -this.oY, -this.oZ);
    draw();
    GL11.glPopMatrix();
  }
  
  public void drawNoBind(float angle, float x, float y, float z)
  {
    GL11.glPushMatrix();
    GL11.glTranslatef(this.oX, this.oY, this.oZ);
    GL11.glRotatef(angle, x, y, z);
    GL11.glTranslatef(-this.oX, -this.oY, -this.oZ);
    drawNoBind();
    GL11.glPopMatrix();
  }
  
  public void drawNoBind()
  {
    for (FaceGroup fg : this.faceGroup) {
      fg.drawNoBind();
    }
  }
  
  public void draw()
  {
    for (FaceGroup fg : this.faceGroup) {
      fg.draw();
    }
  }
  
  public ArrayList<UV> getUV()
  {
    return this.uv;
  }
  
  public ArrayList<FaceGroup> getFaceGroup()
  {
    return this.faceGroup;
  }
  
  public Hashtable<String, Float> getNameToFloatHash()
  {
    return this.nameToFloatHash;
  }
  
  public ArrayList<Vertex> getVertices()
  {
    return this.vertices;
  }
  
  public void setOriginX(float ox)
  {
    this.oX = ox;
  }
  
  public float getOriginX()
  {
    return this.oX;
  }
  
  public void setOriginX2(float ox2)
  {
    this.oX2 = ox2;
  }
  
  public float getOriginX2()
  {
    return this.oX2;
  }
  
  public void setOriginY(float oy)
  {
    this.oY = oy;
  }
  
  public float getOriginY()
  {
    return this.oY;
  }
  
  public void setOriginY2(float oy2)
  {
    this.oY2 = oy2;
  }
  
  public float getOriginY2()
  {
    return this.oY2;
  }
  
  public void setOriginZ(float oz)
  {
    this.oZ = oz;
  }
  
  public float getOriginZ()
  {
    return this.oZ;
  }
  
  public void setOriginZ2(float oz2)
  {
    this.oZ2 = oz2;
  }
  
  public float getOriginZ2()
  {
    return this.oZ2;
  }
  
  public void setMaxX(double maxX)
  {
    this.maxX = maxX;
  }
  
  public double getMaxX()
  {
    return this.maxX;
  }
  
  public void setMaxY(double maxY)
  {
    this.maxY = maxY;
  }
  
  public double getMaxY()
  {
    return this.maxY;
  }
  
  public void setMaxZ(double maxZ)
  {
    this.maxZ = maxZ;
  }
  
  public double getMaxZ()
  {
    return this.maxZ;
  }
  
  public void setMinX(double minX)
  {
    this.minX = minX;
  }
  
  public double getMinX()
  {
    return this.minX;
  }
  
  public void setMinY(double minY)
  {
    this.minY = minY;
  }
  
  public double getMinY()
  {
    return this.minY;
  }
  
  public void setMinZ(double minZ)
  {
    this.minZ = minZ;
  }
  
  public double getMinZ()
  {
    return this.minZ;
  }
}
